@@ -4,43 +4,40 @@ ColourMapLP class definition
 
 import numpy
 
-from bokeh.plotting import Figure
-
-from bokeh.models import ColumnDataSource, Plot, AdaptiveTicker, \
-    NumeralTickFormatter
+from bokeh.model import DataModel
 
+from bokeh.models import ColumnDataSource, Plot, AdaptiveTicker, NumeralTickFormatter
 from bokeh.models.widgets import Button
 from bokeh.models.layouts import Column, Row
+from bokeh.models.widgets import Div
 from bokeh.models.callbacks import CustomJS
 from bokeh.models.tools import HoverTool
 
 from bokeh.core.properties import Instance, String
 
+from bokeh.plotting import figure
+
 from bokcolmaps.ColourMap import ColourMap
 
 from bokcolmaps.get_common_kwargs import get_common_kwargs
+from bokcolmaps.check_kwargs import check_kwargs
 
 
-class ColourMapLP(Row):
+class ColourMapLP(Row, DataModel):
 
     """
     A ColourMap and a line plot of the data against z at the x and y
     coordinates linked to a custom hover tool.
     """
 
-    __view_model__ = 'Row'
-    __subtype__ = 'ColourMapLP'
-
-    __view_module__ = 'bokeh'
-
     cmplot = Instance(ColourMap)
     lpcon = Instance(Column)
     btn = Instance(Button)
     lplot = Instance(Plot)
     lpds = Instance(ColumnDataSource)
-    cmxlab = String
-    cmylab = String
-    js_hover = String
+    _cmxlab = String
+    _cmylab = String
+    _js_hover = String
 
     def __init__(self, x, y, z, dm, **kwargs):
 
@@ -54,10 +51,14 @@ class ColourMapLP(Row):
         hoverdisp: display the hover tool readout if True
         scbutton: create a Snap to Centre button if True (set to False if
                   ColourMapLP not used with Bokeh Server)
+        padleft: padding (pixels) to left of line plot (default 0)
+        padabove: padding (pixels) above line plot (default 0)
         """
 
-        palette, cfile, revcols, xlab, ylab, zlab,\
-            dmlab, rmin, rmax, xran, yran = get_common_kwargs(**kwargs)
+        check_kwargs(kwargs, extra_kwargs=['cmheight', 'cmwidth', 'lpheight', 'lpwidth', 'revz', 'hoverdisp', 'scbutton', 'padleft', 'padabove'])
+
+        palette, cfile, revcols, xlab, ylab, zlab, dmlab, \
+            rmin, rmax, xran, yran, alpha, nan_colour = get_common_kwargs(**kwargs)
 
         cmheight = kwargs.get('cmheight', 575)
         cmwidth = kwargs.get('cmwidth', 500)
@@ -65,7 +66,9 @@ class ColourMapLP(Row):
         lpwidth = kwargs.get('lpwidth', 300)
         revz = kwargs.get('revz', False)
         hoverdisp = kwargs.get('hoverdisp', True)
-        scbutton = kwargs.get('scbutton', True)
+        scbutton = kwargs.get('scbutton', False)
+        padleft = kwargs.get('padleft', 0)
+        padabove = kwargs.get('padabove', 0)
 
         super().__init__()
 
@@ -78,30 +81,34 @@ class ColourMapLP(Row):
                                 palette=palette, cfile=cfile, revcols=revcols,
                                 xlab=xlab, ylab=ylab, zlab=zlab, dmlab=dmlab,
                                 height=cmheight, width=cmwidth, rmin=rmin,
-                                rmax=rmax, xran=xran, yran=yran, hover=False)
+                                rmax=rmax, xran=xran, yran=yran, hover=False,
+                                alpha=alpha, nan_colour=nan_colour)
 
         # Custom hover tool to render profile at cursor position in line plot
-        # JS code appended to existing code in ColourMap
 
-        self.js_hover = self.cmplot.js_hover + """
+        self._js_hover = self.cmplot._js_hover + """
         var lpdata = lpsrc.data;
+        var lx = lpdata['x'];
 
-        if ((xind < x.length) && (yind < y.length)) {
+        if ((xind >= 0) && (xind < x.length) && (yind >= 0) && (yind < y.length)) {
             var dm = data['dm'][0];
-            var lx = lpdata['x'];
 
             var skip = x.length*y.length;
             for (var i = 0; i < lx.length; i++) {
                 lx[i] = dm[zind + i*skip];
             }
-
-            lpsrc.change.emit();
         }
+        else {
+            for (var i = 0; i < lx.length; i++) {
+                lx[i] = NaN;
+            }
+        }
+        lpsrc.change.emit();
         """
 
         cjs = CustomJS(args={'datasrc': self.cmplot.datasrc,
                              'lpsrc': self.lpds},
-                       code=self.js_hover)
+                       code=self._js_hover)
         if hoverdisp:
             htool = HoverTool(tooltips=[(xlab, '@xp{0.00}'),
                                         (ylab, '@yp{0.00}'),
@@ -112,8 +119,8 @@ class ColourMapLP(Row):
 
         self.cmplot.plot.add_tools(htool)
 
-        self.lplot = Figure(x_axis_label=dmlab, y_axis_label=zlab,
-                            plot_height=lpheight, plot_width=lpwidth,
+        self.lplot = figure(x_axis_label=dmlab, y_axis_label=zlab,
+                            height=lpheight, width=lpwidth,
                             tools=['reset, pan, wheel_zoom, box_zoom, save'],
                             toolbar_location='right')
 
@@ -130,6 +137,13 @@ class ColourMapLP(Row):
         self.lplot.line('x', 'y', source=self.lpds, line_color='blue',
                         line_width=2, line_alpha=1)
 
+        self.lplot.title.text = 'Profile at cursor'
+
+        self.lplot.title.text_font = 'garamond'
+        self.lplot.title.text_font_size = '12pt'
+        self.lplot.title.text_font_style = 'bold'
+        self.lplot.title.align = 'center'
+
         self.lplot.xaxis.axis_label_text_font = 'garamond'
         self.lplot.xaxis.axis_label_text_font_size = '10pt'
         self.lplot.xaxis.axis_label_text_font_style = 'bold'
@@ -141,18 +155,21 @@ class ColourMapLP(Row):
         self.lplot.yaxis.axis_label_text_font_size = '10pt'
         self.lplot.yaxis.axis_label_text_font_style = 'bold'
 
-        self.lpcon = Column(self.lplot)
+        self.lpcon = Column(Div(text='', width=lpwidth, height=padabove), self.lplot)
 
         if scbutton:
-            self.btn = Button(label='Snap to centre')
+            self.btn = Button(label='Snap to centre', align='center')
             self.btn.on_click(self.centre_lp)
             self.lpcon.children.append(self.btn)
+        else:
+            self.btn = Button()
 
         self.children.append(self.cmplot)
+        self.children.append(Div(text='', width=padleft, height=padabove + lpheight))
         self.children.append(self.lpcon)
 
-        self.cmxlab = xlab
-        self.cmylab = ylab
+        self._cmxlab = xlab
+        self._cmylab = ylab
 
         self.centre_lp()
 
@@ -174,6 +191,7 @@ class ColourMapLP(Row):
         xa = ds['x'][0]
         ya = ds['y'][0]
         xi, = numpy.where(xa >= x)
+        xind = yind = 0
         if xi.size > 0:
             xind = xi[0]
             if (xind > 0) and (abs(xa[xind - 1] - x) < abs(xa[xind] - x)):
