@@ -2,6 +2,8 @@
 ColourMapLPSlider class definition
 """
 
+from bokeh.model import DataModel
+
 from bokeh.models.widgets import Slider
 from bokeh.models.layouts import Column
 
@@ -10,32 +12,29 @@ from bokeh.core.properties import Instance
 from bokcolmaps.ColourMapLP import ColourMapLP
 
 from bokcolmaps.get_common_kwargs import get_common_kwargs
+from bokcolmaps.check_kwargs import check_kwargs
 
 
-class ColourMapLPSlider(Column):
+class ColourMapLPSlider(Column, DataModel):
 
     """
     A ColourMapLP with a slider linked to the z coordinate
     (i.e. the 2D slice being displayed).
     """
 
-    __view_model__ = 'Column'
-    __subtype__ = 'ColourMapLPSlider'
-
-    __view_module__ = 'bokeh'
-
     cmaplp = Instance(ColourMapLP)
     zslider = Instance(Slider)
 
     def __init__(self, x, y, z, dm, **kwargs):
 
         """
-        All init arguments same as for ColourMapLP (apart from scbutton flag -
-        assumed here as ColourMapLPSlider needs the Bokeh Server)
+        All init arguments same as for ColourMapLP
         """
 
-        palette, cfile, revcols, xlab, ylab, zlab,\
-            dmlab, rmin, rmax, xran, yran = get_common_kwargs(**kwargs)
+        check_kwargs(kwargs, extra_kwargs=['cmheight', 'cmwidth', 'lpheight', 'lpwidth', 'revz', 'hoverdisp', 'scbutton', 'padleft', 'padabove'])
+
+        palette, cfile, revcols, xlab, ylab, zlab, dmlab, \
+            rmin, rmax, xran, yran, alpha, nan_colour = get_common_kwargs(**kwargs)
 
         cmheight = kwargs.get('cmheight', 575)
         cmwidth = kwargs.get('cmwidth', 500)
@@ -43,11 +42,14 @@ class ColourMapLPSlider(Column):
         lpwidth = kwargs.get('lpwidth', 300)
         revz = kwargs.get('revz', False)
         hoverdisp = kwargs.get('hoverdisp', True)
+        scbutton = kwargs.get('scbutton', False)
+        padleft = kwargs.get('padleft', 0)
+        padabove = kwargs.get('padabove', 0)
 
         super().__init__()
 
-        self.height = cmheight
-        self.width = int((cmwidth + lpwidth) * 1.1)
+        self.height = max(cmheight, lpheight)
+        self.width = cmwidth + lpwidth
 
         self.cmaplp = ColourMapLP(x, y, z, dm,
                                   palette=palette, cfile=cfile, revcols=revcols,
@@ -55,12 +57,15 @@ class ColourMapLPSlider(Column):
                                   cmheight=cmheight, cmwidth=cmwidth,
                                   lpheight=lpheight, lpwidth=lpwidth,
                                   rmin=rmin, rmax=rmax, xran=xran, yran=yran,
-                                  revz=revz, hoverdisp=hoverdisp)
+                                  revz=revz, hoverdisp=hoverdisp, scbutton=scbutton,
+                                  alpha=alpha, nan_colour=nan_colour,
+                                  padleft=padleft, padabove=padabove)
 
         self.zslider = Slider(title=zlab + ' index', start=0, end=z.size - 1,
-                              step=1, value=0, orientation='horizontal')
+                              step=1, value=0, orientation='horizontal',
+                              width=self.cmaplp.cmplot.plot.width)
 
-        self.zslider.on_change('value', self.cmaplp.cmplot.input_change)
+        self.zslider.js_on_change('value', self.cmaplp.cmplot.cjs_slider)
 
         self.children.append(Column(self.zslider, width=self.width))
         self.children.append(self.cmaplp)
