@@ -1,6 +1,6 @@
 """
 To run this example at the command line enter:
-python3 ColourMapExample.py
+python ColourMapExample.py
 """
 
 import numpy
@@ -14,11 +14,10 @@ x, y, z, D = example_data()
 D = D[0]  # Data for first value of z
 z = numpy.array([z[0]])  # First value of z
 
-cm = ColourMap(x, y, z, D, cfile='../jet.txt',
-               xlab='x val', ylab='y val', zlab='power val',
-               dmlab='Function val')
+cm = ColourMap(x, y, z, D, xlab='x val', ylab='y val',
+               zlab='power val', dmlab='Function val')
 
 # Calls below not needed, only added for code coverage test
-cm.update_cbar(0)
+cm.update_image(0)
 
 show(cm)
