@@ -1,5 +1,6 @@
 """
-To run this example at the command line enter: python3 SpotPlotExample.py
+To run this example at the command line enter:
+python SpotPlotExample.py
 The example data is the 3D grid used in the ColourMap example. The SpotPlot
 class is for 1D data sections defined at arbitrary x and y coordinates on a
 common z grid, so we'll subsample the 3D grid at a number of random x and y
@@ -32,9 +33,8 @@ for n in range(ns):
     D[n] = Dg[0, yi[n], xi[n]]  # Data for first value of z
 z = z[0]  # First value of z
 
-sp = SpotPlot(x, y, z, D, cfile='../jet.txt',
-              xlab='x val', ylab='y val', zlab='power val',
-              dmlab='Function val')
+sp = SpotPlot(x, y, z, D, xlab='x val', ylab='y val',
+              zlab='power val', dmlab='Function val')
 
 # Calls below not needed, only added for code coverage test
 sp.changed(0)
