@@ -1,8 +1,10 @@
-"""SpotPlot class definition"""
+"""
+SpotPlot class definition
+"""
 
 import numpy
 
-from bokeh.plotting import Figure
+from bokeh.model import DataModel
 
 from bokeh.models import ColumnDataSource, Plot, ColorBar
 from bokeh.models.mappers import LinearColorMapper
@@ -10,26 +12,22 @@ from bokeh.models.layouts import Column
 
 from bokeh.core.properties import Instance, String, Int, Float, Bool
 
+from bokeh.plotting import figure
+
 from bokcolmaps.get_common_kwargs import get_common_kwargs
+from bokcolmaps.check_kwargs import check_kwargs
 from bokcolmaps.generate_colourbar import generate_colourbar
 from bokcolmaps.read_colourmap import read_colourmap
 from bokcolmaps.get_min_max import get_min_max
 
 
-class SpotPlot(Column):
+class SpotPlot(Column, DataModel):
 
     """
     Like a scatter plot but with the points colour mapped with a
     user-defined colour scale.
     """
 
-    __view_model__ = 'Column'
-    __subtype__ = 'SpotPlot'
-
-    __view_module__ = 'bokeh'
-
-    __sizing_mode__ = 'stretch_both'
-
     plot = Instance(Plot)
     cbar = Instance(ColorBar)
 
@@ -38,15 +36,15 @@ class SpotPlot(Column):
     cvals = Instance(ColumnDataSource)
     cmap = Instance(LinearColorMapper)
 
-    title_root = String
-    zlab = String
-    bg_col = String
-    nan_col = String
-    sp_size = Int
-    rmin = Float
-    rmax = Float
-    autoscale = Bool
-    cbdelta = Float
+    _title_root = String
+    _zlab = String
+    _bg_col = String
+    _nan_col = String
+    _sp_size = Int
+    _rmin = Float
+    _rmax = Float
+    _autoscale = Bool
+    _cbdelta = Float
 
     def __init__(self, x, y, z, dm, **kwargs):
 
@@ -61,43 +59,58 @@ class SpotPlot(Column):
             width: plot width (pixels)
         """
 
-        palette, cfile, revcols, xlab, ylab, zlab,\
-            dmlab, rmin, rmax, xran, yran = get_common_kwargs(**kwargs)
+        check_kwargs(kwargs, extra_kwargs=['height', 'width'])
+
+        palette, cfile, revcols, xlab, ylab, zlab, dmlab, \
+            rmin, rmax, xran, yran, alpha, nan_colour = get_common_kwargs(**kwargs)
 
         height = kwargs.get('height', 575)
         width = kwargs.get('width', 500)
 
         super().__init__()
 
-        self.cbdelta = 0.01  # Min colourbar range (used if values are equal)
+        self._cbdelta = 0.01  # Min colourbar range (used if values are equal)
 
-        self.title_root = dmlab
-        self.zlab = zlab
+        self._title_root = dmlab
+        self._zlab = zlab
 
-        self.rmin = rmin
-        self.rmax = rmax
-        self.autoscale = True
-        if (self.rmin is not None) & (self.rmax is not None):
-            self.autoscale = False
+        is3D = True if z.size > 1 else False
 
-        if z.size > 1:  # Default to first 'slice'
+        self._autoscale = True
+        if (rmin is not None) and (rmax is not None):
+            self._autoscale = False
+        else:
+            if rmin is not None:
+                self._rmin = rmin
+            elif is3D:
+                self._rmin = numpy.min(dm[0])
+            else:
+                self._rmin = numpy.min(dm)
+            if rmax is not None:
+                self._rmax = rmax
+            elif is3D:
+                self._rmax = numpy.max(dm[0])
+            else:
+                self._rmax = numpy.max(dm)
+
+        if is3D:  # Default to first 'slice'
             d = dm[0]
         else:
             d = dm
 
-        if self.autoscale:
-            min_val, max_val = get_min_max(d, self.cbdelta)
+        if self._autoscale:
+            min_val, max_val = get_min_max(d, self._cbdelta)
         else:
-            min_val = self.rmin
-            max_val = self.rmax
+            min_val = self._rmin
+            max_val = self._rmax
 
         if cfile is not None:
-            self.read_cmap(cfile)
+            self._read_cmap(cfile)
             palette = self.cvals.data['colours']
             if revcols:
                 self.cvals.data['colours'].reverse()
 
-        self.cmap = LinearColorMapper(palette=palette)
+        self.cmap = LinearColorMapper(palette=palette, nan_color=nan_colour)
 
         if revcols and (cfile is None):
             pal = list(self.cmap.palette)
@@ -110,11 +123,11 @@ class SpotPlot(Column):
         if cfile is None:
             self.cvals = ColumnDataSource(data={'colours': self.cmap.palette})
 
-        self.bg_col = 'black'
-        self.nan_col = 'grey'
-        self.sp_size = int(min(height, width) / 40)
+        self._bg_col = 'black'
+        self._nan_col = nan_colour
+        self._sp_size = int(min(height, width) / 40)
 
-        cols = [self.nan_col] * d.size  # Initially empty
+        cols = [self._nan_col] * d.size  # Initially empty
         self.datasrc = ColumnDataSource(data={'z': [z], 'd': [d], 'dm': [dm]})
         self.coldatasrc = ColumnDataSource(data={'x': x, 'y': y, 'cols': cols})
 
@@ -126,18 +139,19 @@ class SpotPlot(Column):
         if yran is None:
             yran = [y.min(), y.max()]
 
-        self.plot = Figure(x_axis_label=xlab, y_axis_label=ylab,
+        self.plot = figure(x_axis_label=xlab, y_axis_label=ylab,
                            x_range=xran, y_range=yran,
-                           plot_height=height, plot_width=width,
-                           background_fill_color=self.bg_col,
+                           height=height, width=width,
+                           background_fill_color=self._bg_col,
                            tools=ptools, toolbar_location='right')
 
-        self.plot.circle('x', 'y', size=self.sp_size, color='cols',
+        self.plot.circle('x', 'y', size=self._sp_size, color='cols',
                          source=self.coldatasrc,
                          nonselection_fill_color='cols',
                          selection_fill_color='cols',
-                         nonselection_fill_alpha=1, selection_fill_alpha=1,
-                         nonselection_line_alpha=0, selection_line_alpha=1,
+                         fill_alpha=alpha, line_alpha=alpha,
+                         nonselection_fill_alpha=alpha, selection_fill_alpha=alpha,
+                         nonselection_line_alpha=0, selection_line_alpha=alpha,
                          nonselection_line_color='cols',
                          selection_line_color='white', line_width=5)
 
@@ -163,7 +177,7 @@ class SpotPlot(Column):
 
         self.children.append(self.plot)
 
-    def read_cmap(self, fname):
+    def _read_cmap(self, fname):
 
         """
         Read in the colour scale
@@ -194,10 +208,10 @@ class SpotPlot(Column):
         Update the colour scale (needed when the data for display changes)
         """
 
-        if self.autoscale:
+        if self._autoscale:
 
             d = self.datasrc.data['d'][0]
-            min_val, max_val = get_min_max(d, self.cbdelta)
+            min_val, max_val = get_min_max(d, self._cbdelta)
 
             self.cmap.low = min_val
             self.cmap.high = max_val
@@ -234,7 +248,7 @@ class SpotPlot(Column):
 
             else:
 
-                cols[s] = self.nan_col
+                cols[s] = self._nan_col
 
         newdata['cols'] = cols
 
@@ -247,10 +261,10 @@ class SpotPlot(Column):
         """
 
         if self.datasrc.data['z'][0].size > 1:
-            self.plot.title.text = self.title_root + ', ' + \
-                self.zlab + ' = ' + str(self.datasrc.data['z'][0][zind])
+            self.plot.title.text = self._title_root + ', ' + \
+                self._zlab + ' = ' + str(self.datasrc.data['z'][0][zind])
         else:
-            self.plot.title.text = self.title_root
+            self.plot.title.text = self._title_root
 
     def input_change(self, attrname, old, new):
 
