@@ -2,41 +2,35 @@
 SplotPlotLP class definition
 """
 
-from bokeh.plotting import Figure
+from bokeh.model import DataModel
 
-from bokeh.models import ColumnDataSource, Plot, AdaptiveTicker, \
-    NumeralTickFormatter
+from bokeh.models import ColumnDataSource, Plot, AdaptiveTicker, NumeralTickFormatter
 from bokeh.models.layouts import Column, Row
 from bokeh.models.callbacks import CustomJS
 from bokeh.models.tools import TapTool
-from bokeh.models.widgets.markups import Paragraph
+from bokeh.models.widgets import Div
 
-from bokeh.core.properties import Instance, String
+from bokeh.core.properties import Instance
+
+from bokeh.plotting import figure
 
 from bokcolmaps.SpotPlot import SpotPlot
 
 from bokcolmaps.get_common_kwargs import get_common_kwargs
+from bokcolmaps.check_kwargs import check_kwargs
 
 
-class SpotPlotLP(Row):
+class SpotPlotLP(Row, DataModel):
 
     """
     A SpotPlot and a line plot of the data against z at the x and y coordinates
     linked to a custom tap tool.
     """
 
-    __view_model__ = 'Row'
-    __subtype__ = 'SpotPlotLP'
-
-    __view_module__ = 'bokeh'
-
     spplot = Instance(SpotPlot)
     lpcon = Instance(Column)
     lplot = Instance(Plot)
     lpds = Instance(ColumnDataSource)
-    cmxlab = String
-    cmylab = String
-    tstr = String
 
     def __init__(self, x, y, z, dm, **kwargs):
 
@@ -47,16 +41,22 @@ class SpotPlotLP(Row):
         lpheight: line plot height (pixels)
         lpwidth: line plot width (pixels)
         revz: reverse z axis in line plot if True.
+        padleft: padding (pixels) to left of line plot (default 0)
+        padabove: padding (pixels) above line plot (default 0)
         """
 
-        palette, cfile, revcols, xlab, ylab, zlab,\
-            dmlab, rmin, rmax, xran, yran = get_common_kwargs(**kwargs)
+        check_kwargs(kwargs, extra_kwargs=['spheight', 'spwidth', 'lpheight', 'lpwidth', 'revz', 'padleft', 'padabove'])
+
+        palette, cfile, revcols, xlab, ylab, zlab, dmlab, \
+            rmin, rmax, xran, yran, alpha, nan_colour = get_common_kwargs(**kwargs)
 
         spheight = kwargs.get('spheight', 575)
         spwidth = kwargs.get('spwidth', 500)
         lpheight = kwargs.get('lpheight', 500)
         lpwidth = kwargs.get('lpwidth', 300)
         revz = kwargs.get('revz', False)
+        padleft = kwargs.get('padleft', 0)
+        padabove = kwargs.get('padabove', 0)
 
         super().__init__()
 
@@ -83,7 +83,8 @@ class SpotPlotLP(Row):
                                palette=palette, cfile=cfile, revcols=revcols,
                                xlab=xlab, ylab=ylab, zlab=zlab, dmlab=dmlab,
                                height=spheight, width=spwidth, rmin=rmin,
-                               rmax=rmax, xran=xran, yran=yran)
+                               rmax=rmax, xran=xran, yran=yran,
+                               alpha=alpha, nan_colour=nan_colour)
 
         update_lp = CustomJS(args={'dsource': self.lpds,
                                    'psource': self.spplot.plot.renderers[0].data_source},
@@ -92,8 +93,8 @@ class SpotPlotLP(Row):
         ttool = TapTool(callback=update_lp)
         self.spplot.plot.tools.append(ttool)
 
-        self.lplot = Figure(x_axis_label=dmlab, y_axis_label=zlab,
-                            plot_height=lpheight, plot_width=lpwidth,
+        self.lplot = figure(x_axis_label=dmlab, y_axis_label=zlab,
+                            height=lpheight, width=lpwidth,
                             tools=['reset, pan, wheel_zoom, box_zoom, save'],
                             toolbar_location='right')
 
@@ -124,7 +125,8 @@ class SpotPlotLP(Row):
         self.lplot.yaxis.axis_label_text_font_size = '10pt'
         self.lplot.yaxis.axis_label_text_font_style = 'bold'
 
-        self.lpcon = Column(self.lplot, Paragraph(text=''))
+        self.lpcon = Column(Div(text='', width=lpwidth, height=padabove), self.lplot)
 
         self.children.append(self.spplot)
+        self.children.append(Div(text='', width=padleft, height=padabove + lpheight))
         self.children.append(self.lpcon)
