@@ -2,6 +2,8 @@
 SplotPlotLPSlider class definition
 """
 
+from bokeh.model import DataModel
+
 from bokeh.models.widgets import Slider
 from bokeh.models.layouts import Column
 
@@ -10,37 +12,37 @@ from bokeh.core.properties import Instance
 from bokcolmaps.SpotPlotLP import SpotPlotLP
 
 from bokcolmaps.get_common_kwargs import get_common_kwargs
+from bokcolmaps.check_kwargs import check_kwargs
 
 
-class SpotPlotLPSlider(Column):
+class SpotPlotLPSlider(Column, DataModel):
 
     """
     A SpotPlotLP with a slider linked to the z coordinate
     (i.e. the row being displayed).
     """
 
-    __view_model__ = 'Column'
-    __subtype__ = 'SpotPlotLPSlider'
-
-    __view_module__ = 'bokeh'
-
     splotlp = Instance(SpotPlotLP)
     zslider = Instance(Slider)
 
     def __init__(self, x, y, z, dm, **kwargs):
 
         """
-        All init arguments same as for SpotPlotLP.
+        All init arguments same as for SpotPlotLP
         """
 
-        palette, cfile, revcols, xlab, ylab, zlab,\
-            dmlab, rmin, rmax, xran, yran = get_common_kwargs(**kwargs)
+        check_kwargs(kwargs, extra_kwargs=['spheight', 'spwidth', 'lpheight', 'lpwidth', 'revz', 'padleft', 'padabove'])
+
+        palette, cfile, revcols, xlab, ylab, zlab, dmlab, \
+            rmin, rmax, xran, yran, alpha, nan_colour = get_common_kwargs(**kwargs)
 
         spheight = kwargs.get('spheight', 575)
         spwidth = kwargs.get('spwidth', 500)
         lpheight = kwargs.get('lpheight', 500)
         lpwidth = kwargs.get('lpwidth', 300)
         revz = kwargs.get('revz', False)
+        padleft = kwargs.get('padleft', 0)
+        padabove = kwargs.get('padabove', 0)
 
         super(SpotPlotLPSlider, self).__init__()
 
@@ -53,10 +55,12 @@ class SpotPlotLPSlider(Column):
                                   spheight=spheight, spwidth=spwidth,
                                   lpheight=lpheight, lpwidth=lpwidth,
                                   rmin=rmin, rmax=rmax, xran=xran, yran=yran,
-                                  revz=revz)
+                                  revz=revz, alpha=alpha, nan_colour=nan_colour,
+                                  padleft=padleft, padabove=padabove)
 
         self.zslider = Slider(title=zlab + ' index', start=0, end=z.size - 1,
-                              step=1, value=0, orientation='horizontal')
+                              step=1, value=0, orientation='horizontal',
+                              width=self.splotlp.spplot.plot.width)
 
         self.zslider.on_change('value', self.splotlp.spplot.input_change)
 
